@@ -1,4 +1,8 @@
 /*
+ * $Source: /cvs/cgoban/src/cgoban.c,v $
+ * $Revision: 1.2 $
+ * $Date: 2002/02/28 03:34:35 $
+ *
  * src/cgoban.c, part of Complete Goban (game program)
  * Copyright (C) 1995-1996 William Shubert
  * See "configure.h.in" for more copyright information.
@@ -105,6 +109,7 @@ Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
     {"local.x", "", NULL, 0, NULL},
     {"local.y", "", NULL, 0, NULL},
     {"local.bProp", "1.0", NULL, 0, checkBProp},
+    {"local.bPropW", "1.0", NULL, 0, checkBProp},
     {"local.sgfName", "game.sgf", NULL, 0, NULL},
     {"edit.x", "", NULL, 0, NULL},
     {"edit.y", "", NULL, 0, NULL},
@@ -113,6 +118,7 @@ Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
     {"edit.toolW", "0.0", NULL, 0, NULL},
     {"edit.toolH", "0.0", NULL, 0, NULL},
     {"edit.bProp", "1.0", NULL, 0, checkBProp},
+    {"edit.bPropW", "1.0", NULL, 0, checkBProp},
     {"edit.sgfName", "seigen-minoru.sgf", NULL, 0, NULL},
     {"edit.infoX", "", NULL, 0, NULL},
     {"edit.infoY", "", NULL, 0, NULL},
@@ -183,11 +189,13 @@ Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
     {"client.x", "", NULL, 0, NULL},
     {"client.y", "", NULL, 0, NULL},
     {"client.bProp", "1.0", NULL, 0, checkBProp},
+    {"client.bPropW", "1.0", NULL, 0, checkBProp},
     {"client.numberKibitz", "f", NULL, CLPSETUP_BOOL, NULL},
     {"client.noTypo", "f", NULL, CLPSETUP_BOOL, NULL},
     {"client.look.x", "", NULL, 0, NULL},
     {"client.look.y", "", NULL, 0, NULL},
     {"client.look.bProp", "1.0", NULL, 0, checkBProp},
+    {"client.look.bPropW", "1.0", NULL, 0, checkBProp},
     {"client.saykib", "1", NULL, 0, NULL},
     {"client.warnLimit", "30", NULL, 0, NULL},
     {"abut.fsel.x", "", NULL, 0, NULL},
