@@ -173,6 +173,7 @@ void  cliGameList_gotMove(CliGameList *gl, const char *buf)  {
   GoStone  stone;
   CliGame  *g;
   int  time1, time2, stonesLeft1, stonesLeft2;
+  Bool IGS_DeadWorkAround;
 
   assert(MAGIC(gl));
   if (buf[0] == 'G')  {
@@ -270,6 +271,26 @@ void  cliGameList_gotMove(CliGameList *gl, const char *buf)  {
     }
     if (gl->games[gl->defaultGame].board->goban->timers[stone].aux > 0)
       ++gl->games[gl->defaultGame].board->goban->timers[stone].aux;
+
+    IGS_DeadWorkAround = FALSE;
+    /*
+     * IGS notifies the client that dead stone selection has begun
+     * before it notifies the client of the last move made!  This
+     * is a workaround to avoid confusing the client.
+     */
+    if (gl->games[gl->defaultGame].board->game->state
+        == goGameState_selectDead) {
+      if (strcmp(locStr, "Pass") == 0) {
+        /*
+         * We've received a move _after_ the game has already been ended
+         * by IGS.  This must be the last move of the game before it ended.
+         * apply the workaround.
+         */
+        gl->games[gl->defaultGame].board->game->state = goGameState_play;
+        IGS_DeadWorkAround = TRUE;
+      }
+    }
+
     if (!cliBoard_gotMove(gl->games[gl->defaultGame].board, locStr, stone,
 			  moveNum))  {
       Str  errStr;
@@ -281,6 +302,15 @@ void  cliGameList_gotMove(CliGameList *gl, const char *buf)  {
 			     str_chars(&errStr));
       str_deinit(&errStr);
     }
+
+    if (IGS_DeadWorkAround == TRUE) {
+      /*
+       * We revived a game from dead state to add the final passing
+       * move received by from the server.  Return the game to 'select dead'
+       * state.
+       */
+      gl->games[gl->defaultGame].board->game->state = goGameState_selectDead;
+    }
   }
 }
     
