@@ -147,7 +147,7 @@ static bool  writeNode(FILE *f, Sgf *mc, SgfElem *me, int *err,
 
     case sgfType_whoseMove:
       assert(goStone_isStone(me->gVal));
-      str_print(nodeOut, "PL[%d]", (int)(me->gVal == goStone_white) + 1);
+      str_print(nodeOut, "PL[%c]", (me->gVal == goStone_white) ? 'W' : 'B');
       break;
     case sgfType_move:
       str_clip(nodeOut, 0);
